<?php
namespace AutomateWoo\Admin\Analytics\Rest_API\Workflow_Runs;

defined( 'ABSPATH' ) || exit;

use AutomateWoo\Admin\Analytics\Rest_API\Stats_Controller as Analytics_Stats_Controller;
use AutomateWoo\Admin\Analytics\Rest_API\Workflow_Runs\Query as Workflow_Runs_Query;
use stdClass;
use WP_REST_Request;
use WP_REST_Response;

/**
 * REST API Reports workflows stats controller class.
 *
 * @extends Analytics_Stats_Controller
 */
class Stats_Controller extends Analytics_Stats_Controller {

	/**
	 * Route base.
	 *
	 * @var string
	 */
	protected $rest_base = 'reports/workflow-runs/stats';

	/**
	 * Forwards a Workflow Runs Query constructor.
	 *
	 * @param array $query_args Set of args to be forwarded to the constructor.
	 * @return Workflow_Runs_Query
	 */
	protected function construct_query( $query_args ) {
		return new Workflow_Runs_Query( $query_args );
	}


	/**
	 * Prepare a report object for serialization.
	 * Wraps `Generic_Stats_Controller#prepare_item_for_response` with the report-specific filter.
	 *
	 * @param stdClass        $report  Report data.
	 * @param WP_REST_Request $request Request object.
	 * @return WP_REST_Response
	 */
	public function prepare_item_for_response( $report, $request ) {
		$response = parent::prepare_item_for_response( $report, $request );

		/**
		 * Filter a workflow runs report returned from the API.
		 *
		 * Allows modification of the report data right before it is returned.
		 *
		 * @param WP_REST_Response $response The response object.
		 * @param object            $report   The original report object.
		 * @param WP_REST_Request  $request  Request used to generate the response.
		 * @filter automatewoo/analytics/rest/prepare/workflow_runs/stats
		 */
		return apply_filters( 'automatewoo/analytics/rest/prepare/workflow_runs/stats', $response, $report, $request );
	}

	/**
	 * Get the Report's item properties schema.
	 * Will be used by `get_item_schema` as `totals` and `subtotals`.
	 *
	 * To be extended by specific report properites.
	 *
	 * @return array
	 */
	public function get_item_properties_schema() {
		return array(
			'runs' => array(
				'description' => __( 'Number of workflow runs.', 'automatewoo' ),
				'type'        => 'integer',
				'context'     => array( 'view', 'edit' ),
				'readonly'    => true,
			),
		);
	}
	/**
	 * Get the Workflow Runs Report's schema, conforming to JSON Schema.
	 *
	 * @return array
	 */
	public function get_item_schema() {
		$schema          = parent::get_item_schema();
		$schema['title'] = 'report_workflow_runs_stats';

		return $schema;
	}

	/**
	 * Get the query params for collections.
	 * Extend `orderby` enum to allow ordering by `date` and `runs`.
	 *
	 * @return array
	 */
	public function get_collection_params() {
		$params = parent::get_collection_params();

		$params['orderby']['enum'] = array(
			'date',
			'runs',
		);

		return $params;
	}
}
