<?php
/**
 * Class for parameter-based Workflow Runs Report querying
 *
 * Example usage:
 * $args = array(
 *          'before'    => '2018-07-19 00:00:00',
 *          'after'     => '2018-07-05 00:00:00',
 *          'page'      => 2,
 *          'workflows' => array(5, 120),
 *         );
 * $report = new \AutomateWoo\Admin\Analytics\Rest_API\Workflow_Runs\Query( $args );
 * $mydata = $report->get_data();
 */

namespace AutomateWoo\Admin\Analytics\Rest_API\Workflow_Runs;

defined( 'ABSPATH' ) || exit;

use Automattic\WooCommerce\Admin\API\Reports\Query as WooReportsQuery;
use WC_Data_Store;

/**
 * Workflow runs specific Woo Report Query.
 *
 * @see Automattic\WooCommerce\Admin\API\Reports\Query
 */
class Query extends WooReportsQuery {

	/**
	 * Valid fields for Products report.
	 *
	 * @return array
	 */
	protected function get_default_query_vars() {
		return array();
	}

	/**
	 * Get workflows data based on the current query vars.
	 *
	 * @return array
	 */
	public function get_data() {
		$args = apply_filters( 'woocommerce_analytics_aw_workflow_runs_stats_query_args', $this->get_query_vars() );

		$data_store = WC_Data_Store::load( 'report-workflow-runs-stats' );
		$results    = $data_store->get_data( $args );
		return apply_filters( 'woocommerce_analytics_workflow_runs_select_query', $results, $args );
	}

}
